==> kubernetes-model-discovery-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1/EndpointConditionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.discovery.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EndpointConditionsFluentImpl<A extends EndpointConditionsFluent<A>> extends BaseFluent<A> implements EndpointConditionsFluent<A>{
  public EndpointConditionsFluentImpl() {
  }
  public EndpointConditionsFluentImpl(EndpointConditions instance) {
    this.withReady(instance.getReady()); 
    this.withServing(instance.getServing()); 
    this.withTerminating(instance.getTerminating()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Boolean ready;
  private Boolean serving;
  private Boolean terminating;
  private Map<String,Object> additionalProperties;
  public Boolean getReady() {
    return this.ready;
  }
  public A withReady(Boolean ready) {
    this.ready=ready; return (A) this;
  }
  public Boolean hasReady() {
    return this.ready != null;
  }
  public Boolean getServing() {
    return this.serving;
  }
  public A withServing(Boolean serving) {
    this.serving=serving; return (A) this;
  }
  public Boolean hasServing() {
    return this.serving != null;
  }
  public Boolean getTerminating() {
    return this.terminating;
  }
  public A withTerminating(Boolean terminating) {
    this.terminating=terminating; return (A) this;
  }
  public Boolean hasTerminating() {
    return this.terminating != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EndpointConditionsFluentImpl that = (EndpointConditionsFluentImpl) o;
    if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
    if (serving != null ? !serving.equals(that.serving) :that.serving != null) return false;
    if (terminating != null ? !terminating.equals(that.terminating) :that.terminating != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ready,  serving,  terminating,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ready != null) { sb.append("ready:"); sb.append(ready + ","); }
    if (serving != null) { sb.append("serving:"); sb.append(serving + ","); }
    if (terminating != null) { sb.append("terminating:"); sb.append(terminating + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withReady() {
    return withReady(true);
  }
  public A withServing() {
    return withServing(true);
  }
  public A withTerminating() {
    return withTerminating(true);
  }
  
}

==> kubernetes-model-discovery-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1/EndpointConditionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.discovery.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EndpointConditionsFluentImpl<A extends EndpointConditionsFluent<A>> extends BaseFluent<A> implements EndpointConditionsFluent<A>{
  public EndpointConditionsFluentImpl() {
  }
  public EndpointConditionsFluentImpl(EndpointConditions instance) {
    if (instance != null) {
      this.withReady(instance.getReady());
      this.withServing(instance.getServing());
      this.withTerminating(instance.getTerminating());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean ready;
  private Boolean serving;
  private Boolean terminating;
  private Map<String,Object> additionalProperties;
  public Boolean getReady() {
    return this.ready;
  }
  public A withReady(Boolean ready) {
    this.ready=ready; return (A) this;
  }
  public Boolean hasReady() {
    return this.ready != null;
  }
  public Boolean getServing() {
    return this.serving;
  }
  public A withServing(Boolean serving) {
    this.serving=serving; return (A) this;
  }
  public Boolean hasServing() {
    return this.serving != null;
  }
  public Boolean getTerminating() {
    return this.terminating;
  }
  public A withTerminating(Boolean terminating) {
    this.terminating=terminating; return (A) this;
  }
  public Boolean hasTerminating() {
    return this.terminating != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EndpointConditionsFluentImpl that = (EndpointConditionsFluentImpl) o;
    if (!java.util.Objects.equals(ready, that.ready)) return false;

    if (!java.util.Objects.equals(serving, that.serving)) return false;

    if (!java.util.Objects.equals(terminating, that.terminating)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ready,  serving,  terminating,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ready != null) { sb.append("ready:"); sb.append(ready + ","); }
    if (serving != null) { sb.append("serving:"); sb.append(serving + ","); }
    if (terminating != null) { sb.append("terminating:"); sb.append(terminating + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withReady() {
    return withReady(true);
  }
  public A withServing() {
    return withServing(true);
  }
  public A withTerminating() {
    return withTerminating(true);
  }
  
}
